#[non_exhaustive]pub enum Request<'a> {
Destroy,
CreateParams {},
GetDefaultFeedback {},
GetSurfaceFeedback {
surface: WlSurface,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
unbind the factory
Objects created through this interface, especially wl_buffers, will remain valid.
This is a destructor, once sent this object cannot be used any longer.
CreateParams
create a temporary object for buffer parameters
This temporary object is used to collect multiple dmabuf handles into a single batch to create a wl_buffer. It can only be used once and should be destroyed after a ‘created’ or ‘failed’ event has been received.
GetDefaultFeedback
get default feedback
This request creates a new wp_linux_dmabuf_feedback object not bound to a particular surface. This object will deliver feedback about dmabuf parameters to use if the client doesn’t support per-surface feedback (see get_surface_feedback).
Only available since version 4 of the interface
GetSurfaceFeedback
get feedback for a surface
This request creates a new wp_linux_dmabuf_feedback object for the specified wl_surface. This object will deliver feedback about dmabuf parameters to use for buffers attached to this surface.
If the surface is destroyed before the wp_linux_dmabuf_feedback object, the feedback object becomes inert.
Only available since version 4 of the interface